@@ -20,19 +20,21 @@
 
 /* these includes are needed for Qt support */
 #include <qpainter.h>
+//Added by qt3to4:
+#include <QPaintEvent>
 
-FactorizedWidget::FactorizedWidget(QWidget * parent, const char * name, const uintList para_factors) :
-			FractionBaseWidget(parent, name), m_factors(para_factors)
+FactorizedWidget::FactorizedWidget(QWidget * parent, const uintList para_factors) :
+			FractionBaseWidget(parent), m_factors(para_factors)
 {
 #ifdef DEBUG
-	kdDebug() << "constructor FactorizedWidget" << endl;
+	kDebug() << "constructor FactorizedWidget";
 #endif
 }
 
 FactorizedWidget::~FactorizedWidget()
 {
 #ifdef DEBUG
-	kdDebug() << "destructor FactorizedWidget" << endl;
+	kDebug() << "destructor FactorizedWidget";
 #endif
 }
 
@@ -62,7 +64,7 @@ void FactorizedWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 	paint.setPen(pen);
 
 	// get the font height; the font height doesn't change while painting
-	QFontMetrics  fm(paint.fontMetrics());
+	QFontMetrics fm(paint.fontMetrics());
 
 	// now we can correctly set the height of the widget
 	setMinimumHeight(fm.lineSpacing());
@@ -71,7 +73,7 @@ void FactorizedWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 	QString tmpStr;
 	int fontHeight = fm.lineSpacing(); // get the font height
 
-	for (uint tmpInt = 0; tmpInt < m_factors.count(); tmpInt++)
+	for (int tmpInt = 0; tmpInt < m_factors.count(); tmpInt++)
 	{
 		// set color for operation sign
 		pen.setColor(m_colorOperation);
@@ -80,12 +82,12 @@ void FactorizedWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 		if (tmpInt == 0)
 		{
 			fontWidth = fm.width("=");
-			paint.drawText(x_pos, 0, fontWidth, fontHeight, AlignCenter, "=");
+			paint.drawText(x_pos, 0, fontWidth, fontHeight, Qt::AlignCenter, "=");
 			x_pos += fontWidth;
 			x_pos += _MARGIN_X;
 		} else {
 			fontWidth = fm.width("*");
-			paint.drawText(x_pos, 0, fontWidth, fontHeight, AlignCenter, "*");
+			paint.drawText(x_pos, 0, fontWidth, fontHeight, Qt::AlignCenter, "*");
 			x_pos += fontWidth;
 			x_pos += _MARGIN_X;
 		}
@@ -97,7 +99,7 @@ void FactorizedWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 		tmpStr.setNum(m_factors[tmpInt]);
 
 		fontWidth = fm.width(tmpStr);
-		paint.drawText(x_pos, 0, fontWidth, fontHeight, AlignCenter, tmpStr);
+		paint.drawText(x_pos, 0, fontWidth, fontHeight, Qt::AlignCenter, tmpStr);
 		x_pos += fontWidth;
 		x_pos += _MARGIN_X;
 	}
