@@ -25,26 +25,28 @@
 #include <qtimer.h>
 
 #include <kaction.h>
-#include <kapplication.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kedittoolbar.h>
 #include <kfiledialog.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 #include <klibloader.h>
 #include <klocale.h>
+#include <kactioncollection.h>
 #include <kmessagebox.h>
+#include <krecentfilesaction.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <ktip.h>
 #include <kurl.h>
-#include <kurldrag.h>
-
+#include <kxmlguifactory.h>
+#include <kapplication.h>
 #include <assert.h>
 
 Kig::Kig()
-  : KParts::MainWindow( 0L, "Kig" ), m_part( 0 )
+  : KParts::MainWindow(), m_part( 0 )
 {
+  setObjectName( QLatin1String( "Kig" ) );
   // setting the configation file
   config = new KConfig( "kigrc" );
   // set the shell's ui resource file
@@ -61,21 +63,21 @@ Kig::Kig()
   // be able to load its dll modules..  Another part of the problem is
   // that boost.python fails to link against python ( on Debian at
   // least ).
-  KLibrary* library = KLibLoader::self()->globalLibrary("libkigpart");
-  KLibFactory* factory = 0;
+  KLibrary* library = KLibLoader::self()->library( "kigpart", QLibrary::ExportExternalSymbolsHint );
+  KPluginFactory* factory = 0;
   if ( library ) factory = library->factory();
   if (factory)
   {
       // now that the Part is loaded, we cast it to a Part to get
       // our hands on it
-      m_part = static_cast<KParts::ReadWritePart*>
-               (factory->create(this, "kig_part", "KParts::ReadWritePart" ));
+      m_part = factory->create< KParts::ReadWritePart >( this );
       if (m_part)
       {
 	  // tell the KParts::MainWindow that this is indeed the main widget
 	  setCentralWidget(m_part->widget());
 
 	  // and integrate the part's GUI with the shell's
+	  // FIXME!!! disabling for now as it seems to create a unending loop
 	  createGUI(m_part);
 	  // finally show tip-of-day ( if the user wants it :) )
 	  QTimer::singleShot( 0, this, SLOT( startupTipOfDay() ) );
@@ -99,60 +101,51 @@ Kig::Kig()
 
 Kig::~Kig()
 {
-  m_recentFilesAction->saveEntries(config);
+  m_recentFilesAction->saveEntries(config->group( QString() ));
   delete config;
 }
 
 void Kig::setupActions()
 {
-  KStdAction::openNew(this, SLOT(fileNew()), actionCollection());
-  KStdAction::open(this, SLOT(fileOpen()), actionCollection());
-  KStdAction::quit(this, SLOT(close()), actionCollection());
+  KStandardAction::openNew(this, SLOT(fileNew()), actionCollection());
+  KStandardAction::open(this, SLOT(fileOpen()), actionCollection());
+  KStandardAction::quit(this, SLOT(close()), actionCollection());
 
-#ifdef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
-  m_toolbarAction = KStdAction::showToolbar(this, SLOT(optionsShowToolbar()), actionCollection());
-  m_statusbarAction = KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
-#else
   createStandardStatusBarAction();
   setStandardToolBarMenuEnabled(true);
-#endif
 
   // FIXME: this (recent files) should be app-wide, not specific to each window...
-  m_recentFilesAction = KStdAction::openRecent(this, SLOT(openURL(const KURL&)), actionCollection());
-  m_recentFilesAction->loadEntries(config);
+  m_recentFilesAction = KStandardAction::openRecent( this, SLOT( openUrl( const KUrl& ) ), actionCollection() );
+  m_recentFilesAction->loadEntries(config->group( QString() ) );
 
-#if KDE_IS_VERSION( 3, 2, 90 )
-  KStdAction::keyBindings( guiFactory(), SLOT( configureShortcuts() ), actionCollection() );
-#else
-  KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
-#endif
-  KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
+  KStandardAction::keyBindings( guiFactory(), SLOT( configureShortcuts() ), actionCollection() );
+  KStandardAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
 
-  KStdAction::tipOfDay( this, SLOT( tipOfDay() ), actionCollection(), "help_tipofday" );
+  KStandardAction::tipOfDay( this, SLOT( tipOfDay() ), actionCollection() );
 }
 
-void Kig::saveProperties(KConfig* config)
+void Kig::saveProperties(KConfigGroup &config)
 {
   // the 'config' object points to the session managed
   // config file.  anything you write here will be available
   // later when this app is restored
-  config->writePathEntry("fileName", m_part->url().path());
+  config.writePathEntry("fileName", m_part->url().path());
 }
 
-void Kig::readProperties(KConfig* config)
+void Kig::readProperties(const KConfigGroup &config)
 {
   // the 'config' object points to the session managed
   // config file.  this function is automatically called whenever
   // the app is being restored.  read in here whatever you wrote
   // in 'saveProperties'
-  load ( KURL(config->readPathEntry("fileName")));
+  load( KUrl( config.readPathEntry( "fileName", QString() ) ) );
 }
 
-void Kig::load(const KURL& url)
+void Kig::load( const KUrl& url )
 {
   // we check for m_part not being 0, because in the case of us not
   // finding our library, we would otherwise get a crash...
-  if ( m_part && m_part->openURL( url ) ) m_recentFilesAction->addURL( url );
+  if ( m_part && m_part->openUrl( url ) ) m_recentFilesAction->addUrl( url );
 }
 
 void Kig::fileNew()
@@ -167,7 +160,7 @@ void Kig::fileNew()
     (new Kig)->show();
 }
 
-void Kig::openURL(const KURL& url)
+void Kig::openUrl( const KUrl& url )
 {
   // Called for opening a file by either the KRecentFilesAction or our
   // own fileOpen() method.
@@ -185,32 +178,20 @@ void Kig::openURL(const KURL& url)
   };
 }
 
-void Kig::optionsConfigureKeys()
-{
-#if KDE_IS_VERSION( 3, 2, 90 )
-  assert( false );
-#else
-  KKeyDialog dlg( true, this );
-  dlg.insert( actionCollection() );
-  dlg.insert( m_part->actionCollection() );
-  (void) dlg.configure( true );
-#endif
-}
-
 void Kig::optionsConfigureToolbars()
 {
-  saveMainWindowSettings(KGlobal::config(), "MainWindow");
+  saveMainWindowSettings(KGlobal::config()->group( "MainWindow") );
 
   // use the standard toolbar editor
-  KEditToolbar dlg(factory());
-  connect(&dlg, SIGNAL(newToolbarConfig()),
+  KEditToolBar dlg(factory());
+  connect(&dlg, SIGNAL(newToolBarConfig()),
 	  this, SLOT(applyNewToolbarConfig()));
   dlg.exec();
 }
 
 void Kig::applyNewToolbarConfig()
 {
-  applyMainWindowSettings(KGlobal::config(), "MainWindow");
+  applyMainWindowSettings(KGlobal::config()->group( "MainWindow") );
 }
 
 bool Kig::queryClose()
@@ -219,8 +200,8 @@ bool Kig::queryClose()
   switch( KMessageBox::warningYesNoCancel
 	  (
 	   widget(),
-	   i18n("Save changes to document %1?").arg(m_part->url().path()),
-	   i18n("Save Changes?"),KStdGuiItem::save(),KStdGuiItem::discard()
+	   i18n("Save changes to document %1?", m_part->url().path()),
+	   i18n("Save Changes?"),KStandardGuiItem::save(),KStandardGuiItem::discard()
 	   ))
     {
     case KMessageBox::Yes:
@@ -238,27 +219,24 @@ bool Kig::queryClose()
 
 void Kig::dragEnterEvent(QDragEnterEvent* e)
 {
-  e->accept(KURLDrag::canDecode(e));
+  e->setAccepted( KUrl::List::canDecode( e->mimeData() ) );
 }
 
 void Kig::dropEvent(QDropEvent* e)
 {
-  KURL::List urls;
-  if ( KURLDrag::decode (e, urls) )
-    {
-      for (KURL::List::iterator u = urls.begin(); u != urls.end(); ++u)
-	{
-	   Kig* k = new Kig;
-	   k->show();
-	   k->load(*u);
-	};
-    };
+  KUrl::List urls = KUrl::List::fromMimeData( e->mimeData() );
+  for ( KUrl::List::iterator u = urls.begin(); u != urls.end(); ++u )
+  {
+    Kig* k = new Kig();
+    k->show();
+    k->load( *u );
+  }
 }
 
 void Kig::fileOpen()
 {
   QString formats =
-     i18n( "*.kig *.kigz *.kgeo *.seg|All Supported Files (*.kig *.kigz *.kgeo *.seg)\n"
+     i18n( "*.kig *.kigz *.seg *.fgeo *.fig *.FIG|All Supported Files (*.kig *.kigz *.seg *.fgeo *.fig)\n"
            "*.kig|Kig Documents (*.kig)\n"
            "*.kigz|Compressed Kig Documents (*.kigz)\n"
            "*.kgeo|KGeo Documents (*.kgeo)\n"
@@ -266,43 +244,16 @@ void Kig::fileOpen()
            "*.fgeo|Dr. Geo Documents (*.fgeo)\n"
            "*.fig *.FIG|Cabri Documents (*.fig *.FIG)" );
 
-  // this slot is connected to the KStdAction::open action...
-  QString file_name = KFileDialog::getOpenFileName(":document", formats );
+  // this slot is connected to the KStandardAction::open action...
+  QString file_name = KFileDialog::getOpenFileName( KUrl( "kfiledialog:///document" ), formats );
 
-  if (!file_name.isEmpty()) openURL(file_name);
+  if (!file_name.isEmpty()) openUrl(file_name);
 }
 
-// ifdef's disabled, cause Qt moc doesn't handle ifdef's..
-// #ifdef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
-void Kig::optionsShowToolbar()
-{
-#ifdef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
-  if (m_toolbarAction->isChecked())
-    toolBar()->show();
-  else
-    toolBar()->hide();
-#else
-  assert( false );
-#endif
-}
-
-void Kig::optionsShowStatusbar()
-{
-#ifdef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
-  if (m_statusbarAction->isChecked())
-    statusBar()->show();
-  else
-    statusBar()->hide();
-#else
-  assert( false );
-#endif
-}
-// #endif
-
 void Kig::tipOfDay() {
-  KTipDialog::showTip( "kig/tips", true );
+  KTipDialog::showTip(this, "kig/tips", true);
 }
 
 void Kig::startupTipOfDay() {
-  KTipDialog::showTip( "kig/tips" );
+  KTipDialog::showTip(this, "kig/tips");
 }
