@@ -19,7 +19,6 @@
 **/
 
 #include "kig_commands.h"
-#include "kig_commands.moc"
 
 #include "kig_part.h"
 #include "kig_document.h"
@@ -46,7 +45,7 @@ public:
 };
 
 KigCommand::KigCommand( KigPart& doc, const QString& name )
-  : KNamedCommand(name), d( new Private( doc ) )
+  : QUndoCommand( name ), d( new Private( doc ) )
 {
 }
 
@@ -57,14 +56,14 @@ KigCommand::~KigCommand()
   delete d;
 }
 
-void KigCommand::execute()
+void KigCommand::redo()
 {
   for ( uint i = 0; i < d->tasks.size(); ++i )
     d->tasks[i]->execute( d->doc );
   d->doc.redrawScreen();
 }
 
-void KigCommand::unexecute()
+void KigCommand::undo()
 {
   for ( uint i = 0; i < d->tasks.size(); ++i )
     d->tasks[i]->unexecute( d->doc );
@@ -97,7 +96,7 @@ KigCommand* KigCommand::removeCommand( KigPart& doc, const std::vector<ObjectHol
   if ( os.size() == 1 )
     text = os.back()->imp()->type()->removeAStatement();
   else
-    text = i18n( "Remove %1 Objects" ).arg( os.size() );
+    text = i18n( "Remove %1 Objects", os.size() );
   KigCommand* ret = new KigCommand( doc, text );
   ret->addTask( new RemoveObjectsTask( os ) );
   return ret;
@@ -109,7 +108,7 @@ KigCommand* KigCommand::addCommand( KigPart& doc, const std::vector<ObjectHolder
   if ( os.size() == 1 )
     text = os.back()->imp()->type()->addAStatement();
   else
-    text = i18n( "Add %1 Objects" ).arg( os.size() );
+    text = i18n( "Add %1 Objects", os.size() );
   KigCommand* ret = new KigCommand( doc, text );
   ret->addTask( new AddObjectsTask( os ) );
   return ret;
