@@ -52,6 +52,28 @@ ObjectTypeCalcer* ObjectFactory::fixedPointCalcer( const Coordinate& c ) const
   return oc;
 }
 
+ObjectHolder* ObjectFactory::numericValue(
+  const double value, const Coordinate& loc, const KigDocument& doc ) const
+{
+  return new ObjectHolder( numericValueCalcer( value, loc, doc ) );
+}
+
+ObjectTypeCalcer* ObjectFactory::numericValueCalcer(
+  const double value, const Coordinate& loc, const KigDocument& doc ) const
+{
+  std::vector<ObjectCalcer*> parents;
+  parents.reserve( 4 );
+  const bool needframe = false;
+  parents.push_back( new ObjectConstCalcer( new IntImp( needframe ? 1 : 0 ) ) );
+  parents.push_back( getAttachPoint( 0, loc, doc ) );
+  parents.push_back( new ObjectConstCalcer( new StringImp( "%1" ) ) );
+  parents.push_back( new ObjectConstCalcer( new DoubleImp( value ) ) );
+
+  ObjectTypeCalcer* ret = new ObjectTypeCalcer( NumericTextType::instance(), parents );
+  ret->calc( doc );
+  return ret;
+}
+
 ObjectTypeCalcer* ObjectFactory::cursorPointCalcer( const Coordinate& c ) const
 {
   std::vector<ObjectCalcer*> args;
@@ -77,7 +99,7 @@ ObjectTypeCalcer* ObjectFactory::sensiblePointCalcer(
     std::vector<ObjectCalcer*> args;
     args.push_back( os[0]->calcer() );
     args.push_back( os[1]->calcer() );
-    // the simpliest case: two lines...
+    // the simplest case: two lines...
     if ( ( os[0]->imp()->inherits( AbstractLineImp::stype() ) ) &&
          ( os[1]->imp()->inherits( AbstractLineImp::stype() ) ) )
       return new ObjectTypeCalcer( LineLineIntersectionType::instance(), args );
@@ -167,7 +189,7 @@ ObjectTypeCalcer* ObjectFactory::locusCalcer(
   std::vector<ObjectCalcer*> realparents( 2 + sideOfTree.size(), 0 );
   realparents[0] = new ObjectConstCalcer( new HierarchyImp( hier ) );
   realparents[1] = curve;
-  copy( sideOfTree.begin(), sideOfTree.end(), realparents.begin() + 2 );
+  std::copy( sideOfTree.begin(), sideOfTree.end(), realparents.begin() + 2 );
 
   return new ObjectTypeCalcer( LocusType::instance(), realparents );
 }
@@ -277,9 +299,9 @@ ObjectHolder* ObjectFactory::attachedLabel(
 ObjectPropertyCalcer* ObjectFactory::propertyObjectCalcer(
   ObjectCalcer* o, const char* p ) const
 {
-  int wp = o->imp()->propertiesInternalNames().findIndex( p );
+  int wp = o->imp()->propertiesInternalNames().indexOf( p );
   if ( wp == -1 ) return 0;
-  return new ObjectPropertyCalcer( o, wp );
+  return new ObjectPropertyCalcer( o, p );
 }
 
 ObjectHolder* ObjectFactory::propertyObject(
