@@ -47,12 +47,17 @@
 #include "thumbnailpicker.h"
 #include "Options.h"
 
+#include <config-kstars.h>
+
+#ifdef HAVE_INDI_H
 #include "indielement.h"
 #include "indiproperty.h"
 #include "indidevice.h"
 #include "indimenu.h"
 #include "devicemanager.h"
 #include "indistd.h"
+#endif
+
 #include "skycomponents/constellationboundary.h"
 
 DetailDialog::DetailDialog(SkyObject *o, const KStarsDateTime &ut, GeoLocation *geo, QWidget *parent )
@@ -97,7 +102,11 @@ void DetailDialog::createGeneralTab()
     //Connections
     connect( Data->ObsListButton, SIGNAL( clicked() ), this, SLOT( addToObservingList() ) );
     connect( Data->CenterButton, SIGNAL( clicked() ), this, SLOT( centerMap() ) );
+    #ifdef HAVE_INDI_H
     connect( Data->ScopeButton, SIGNAL( clicked() ), this, SLOT( centerTelescope() ) );
+    #else
+    Data->ScopeButton->setEnabled(false);
+    #endif
     connect( Data->Image, SIGNAL( clicked() ), this, SLOT( updateThumbnail() ) );
 
     //Show object thumbnail image
@@ -115,6 +124,11 @@ void DetailDialog::createGeneralTab()
         s = (StarObject *)selectedObject;
 
         Data->Names->setText( s->longname() );
+        if( s->getHDIndex() != 0 )
+            if( !s->longname().isEmpty() )
+                Data->Names->setText( s->longname() + QString( ", HD%1" ).arg( QString::number( s->getHDIndex() ) ) );
+            else
+                Data->Names->setText( QString( ", HD%1" ).arg( QString::number( s->getHDIndex() ) ) );
         Data->Type->setText( s->sptype() + ' ' + i18n("star") );
         Data->Magnitude->setText( i18nc( "number in magnitudes", "%1 mag" ,
                                          KGlobal::locale()->formatNumber( s->mag(), 1 ) ) );  //show to tenths place
@@ -163,7 +177,7 @@ void DetailDialog::createGeneralTab()
             Data->Type->setText( i18n("G5 star") );
         else if ( ps->name() == "Moon" )
             Data->Type->setText( ps->translatedName() );
-        else if ( ps->name() == "Pluto" || ps->name() == "Ceres" || ps->name() == "Eris" )
+        else if ( ps->name() == i18n("Pluto") || ps->name() == "Ceres" || ps->name() == "Eris" ) // TODO: Check if Ceres / Eris have translations and i18n() them
             Data->Type->setText( i18n("Dwarf planet") );
         else
             Data->Type->setText( ps->typeName() );
@@ -269,7 +283,7 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
     //because we don't want a thousands-place separator!
     QString sEpoch = QString::number( ut.epoch(), 'f', 1 );
     //Replace the decimal point with localized decimal symbol
-    sEpoch.replace( ".", KGlobal::locale()->decimalSymbol() );
+    sEpoch.replace( '.', KGlobal::locale()->decimalSymbol() );
 
     Pos->RALabel->setText( i18n( "RA (%1):", sEpoch ) );
     Pos->DecLabel->setText( i18n( "Dec (%1):", sEpoch ) );
@@ -356,13 +370,13 @@ void DetailDialog::createLinksTab()
     Links->InfoTitle->setPalette( titlePalette );
     Links->ImagesTitle->setPalette( titlePalette );
 
-    foreach ( const QString &s, selectedObject->InfoTitle )
-    Links->InfoTitleList->addItem( s );
+    foreach ( const QString &s, selectedObject->InfoTitle() )
+        Links->InfoTitleList->addItem( i18nc( "Image/info menu item (should be translated)", s.toLocal8Bit() ) );
 
     //Links->InfoTitleList->setCurrentRow(0);
 
-    foreach ( const QString &s, selectedObject->ImageTitle )
-    Links->ImageTitleList->addItem( s );
+    foreach ( const QString &s, selectedObject->ImageTitle() )
+        Links->ImageTitleList->addItem( i18nc( "Image/info menu item (should be translated)", s.toLocal8Bit() ) );
 
      updateButtons();
 
@@ -420,10 +434,10 @@ void DetailDialog::createLogTab()
 
     Log->LogTitle->setPalette( titlePalette );
 
-    if ( selectedObject->userLog.isEmpty() )
+    if ( selectedObject->userLog().isEmpty() )
         Log->UserLog->setText(i18n("Record here observation logs and/or data on %1.", selectedObject->translatedName()));
     else
-        Log->UserLog->setText(selectedObject->userLog);
+        Log->UserLog->setText(selectedObject->userLog());
 
     //Automatically save the log contents when the widget loses focus
     connect( Log->UserLog, SIGNAL( focusOut() ), this, SLOT( saveLogData() ) );
@@ -442,12 +456,12 @@ void DetailDialog::viewLink()
     if (m_CurrentLink == NULL) return;
 
     if ( m_CurrentLink->listWidget() == Links->InfoTitleList ) {
-        int i = selectedObject->InfoTitle.indexOf( m_CurrentLink->text() );
-        if (i >= 0) URL = QString( selectedObject->InfoList.at( i ) );
+        int i = selectedObject->InfoTitle().indexOf( m_CurrentLink->text() );
+        if (i >= 0) URL = QString( selectedObject->InfoList().at( i ) );
     }
     else if ( m_CurrentLink->listWidget() == Links->ImageTitleList ) {
-        int i = selectedObject->ImageTitle.indexOf( m_CurrentLink->text() );
-        if (i >= 0) URL = QString( selectedObject->ImageList.at( i ) );
+        int i = selectedObject->ImageTitle().indexOf( m_CurrentLink->text() );
+        if (i >= 0) URL = QString( selectedObject->ImageList().at( i ) );
     }
 
     if ( !URL.isEmpty() )
@@ -459,10 +473,10 @@ void DetailDialog::updateLists()
     Links->InfoTitleList->clear();
     Links->ImageTitleList->clear();
 
-    foreach ( const QString &s, selectedObject->InfoTitle )
+    foreach ( const QString &s, selectedObject->InfoTitle() )
     Links->InfoTitleList->addItem( s );
 
-    foreach ( const QString &s, selectedObject->ImageTitle )
+    foreach ( const QString &s, selectedObject->ImageTitle() )
     Links->ImageTitleList->addItem( s );
 
     updateButtons();
@@ -496,11 +510,11 @@ void DetailDialog::editLinkDialog()
 
     if ( m_CurrentLink->listWidget() == Links->InfoTitleList )
     {
-        row = selectedObject->InfoTitle.indexOf( m_CurrentLink->text() );
+        row = selectedObject->InfoTitle().indexOf( m_CurrentLink->text() );
         if ( row < 0 ) return;
 
         currentItemTitle = m_CurrentLink->text();
-        currentItemURL   = selectedObject->InfoList[row];
+        currentItemURL   = selectedObject->InfoList()[row];
         search_line = selectedObject->name();
         search_line += ':';
         search_line += currentItemTitle;
@@ -510,11 +524,11 @@ void DetailDialog::editLinkDialog()
     }
     else if ( m_CurrentLink->listWidget() == Links->ImageTitleList )
     {
-        row = selectedObject->ImageTitle.indexOf( m_CurrentLink->text() );
+        row = selectedObject->ImageTitle().indexOf( m_CurrentLink->text() );
         if ( row < 0 ) return;
 
         currentItemTitle = m_CurrentLink->text();
-        currentItemURL   = selectedObject->ImageList[row];
+        currentItemURL   = selectedObject->ImageList()[row];
         search_line = selectedObject->name();
         search_line += ':';
         search_line += currentItemTitle;
@@ -557,13 +571,13 @@ void DetailDialog::editLinkDialog()
 
         // Info Link
         if (type==0) {
-            selectedObject->InfoTitle.replace(row, editNameField.text());
-            selectedObject->InfoList.replace(row, editLinkField.text());
+            selectedObject->InfoTitle().replace(row, editNameField.text());
+            selectedObject->InfoList().replace(row, editLinkField.text());
 
         // Image Links
         } else {
-            selectedObject->ImageTitle.replace(row, editNameField.text());
-            selectedObject->ImageList.replace(row, editLinkField.text());
+            selectedObject->ImageTitle().replace(row, editNameField.text());
+            selectedObject->ImageList().replace(row, editLinkField.text());
         }
 
         // Update local files
@@ -591,9 +605,9 @@ void DetailDialog::removeLinkDialog()
 
     if ( m_CurrentLink->listWidget() == Links->InfoTitleList )
     {
-        row = selectedObject->InfoTitle.indexOf( m_CurrentLink->text() );
+        row = selectedObject->InfoTitle().indexOf( m_CurrentLink->text() );
         currentItemTitle = m_CurrentLink->text();
-        currentItemURL   = selectedObject->InfoList[row];
+        currentItemURL   = selectedObject->InfoList()[row];
         LineEntry = selectedObject->name();
         LineEntry += ':';
         LineEntry += currentItemTitle;
@@ -603,9 +617,9 @@ void DetailDialog::removeLinkDialog()
     }
     else if ( m_CurrentLink->listWidget() == Links->ImageTitleList )
     {
-        row = selectedObject->ImageTitle.indexOf( m_CurrentLink->text() );
+        row = selectedObject->ImageTitle().indexOf( m_CurrentLink->text() );
         currentItemTitle = m_CurrentLink->text();
-        currentItemURL   = selectedObject->ImageList[row];
+        currentItemURL   = selectedObject->ImageList()[row];
         LineEntry = selectedObject->name();
         LineEntry += ':';
         LineEntry += currentItemTitle;
@@ -620,13 +634,13 @@ void DetailDialog::removeLinkDialog()
 
     if (type ==0)
     {
-        selectedObject->InfoTitle.removeAt(row);
-        selectedObject->InfoList.removeAt(row);
+        selectedObject->InfoTitle().removeAt(row);
+        selectedObject->InfoList().removeAt(row);
     }
     else
     {
-        selectedObject->ImageTitle.removeAt(row);
-        selectedObject->ImageList.removeAt(row);
+        selectedObject->ImageTitle().removeAt(row);
+        selectedObject->ImageList().removeAt(row);
     }
 
     // Remove link from file
@@ -820,7 +834,7 @@ void DetailDialog::centerMap() {
 
 void DetailDialog::centerTelescope()
 {
-
+#ifdef HAVE_INDI_H
     INDI_D *indidev(NULL);
     INDI_P *prop(NULL), *onset(NULL);
     INDI_E *RAEle(NULL), *DecEle(NULL), *AzEle(NULL), *AltEle(NULL), *ConnectEle(NULL), *nameEle(NULL);
@@ -831,17 +845,17 @@ void DetailDialog::centerTelescope()
     // Find the first device with EQUATORIAL_EOD_COORD or EQUATORIAL_COORD and with SLEW element
     // i.e. the first telescope we find!
 
-    INDIMenu *imenu = ksw->getINDIMenu();
+    INDIMenu *imenu = ksw->indiMenu();
     for ( int i=0; i < imenu->managers.size() ; i++ )
     {
         for ( int j=0; j < imenu->managers.at(i)->indi_dev.size(); j++ )
         {
             indidev = imenu->managers.at(i)->indi_dev.at(j);
             indidev->stdDev->currentObject = NULL;
-            prop = indidev->findProp("EQUATORIAL_EOD_COORD");
+            prop = indidev->findProp("EQUATORIAL_EOD_COORD_REQUEST");
             if (prop == NULL)
             {
-                prop = indidev->findProp("EQUATORIAL_COORD");
+                prop = indidev->findProp("EQUATORIAL_EOD_COORD");
                 if (prop == NULL)
                 {
                     prop = indidev->findProp("HORIZONTAL_COORD");
@@ -944,7 +958,7 @@ void DetailDialog::centerTelescope()
 
     // We didn't find any telescopes
     KMessageBox::sorry(0, i18n("KStars did not find any active telescopes."));
-
+#endif
 }
 
 void DetailDialog::showThumbnail() {
@@ -961,7 +975,7 @@ void DetailDialog::showThumbnail() {
     //If no image found, load "no image" image
     //If that isn't found, make it blank.
     QFile file;
-    QString fname = "thumb-" + selectedObject->name().toLower().replace( QRegExp(" "), QString() ) + ".png";
+    QString fname = "thumb-" + selectedObject->name().toLower().remove( ' ' ) + ".png";
     if ( KSUtils::openDataFile( file, fname ) ) {
         file.close();
         Thumbnail->load( file.fileName(), "PNG" );
@@ -980,7 +994,7 @@ void DetailDialog::updateThumbnail() {
     ThumbnailPicker tp( selectedObject, *Thumbnail, this );
 
     if ( tp.exec() == QDialog::Accepted ) {
-        QString fname = KStandardDirs::locateLocal( "appdata", "thumb-" + selectedObject->name().toLower().replace( QRegExp(" "), QString() ) + ".png" );
+        QString fname = KStandardDirs::locateLocal( "appdata", "thumb-" + selectedObject->name().toLower().remove( ' ' ) + ".png" );
 
         Data->Image->setPixmap( *(tp.image()) );
 
