@@ -23,19 +23,44 @@
 #include <QPoint>
 #include <QMatrix>
 
-#include "ksplanet.h"
 #include "kstarsdata.h"
 #include "ksutils.h"
 #include "ksnumbers.h"
 #include "Options.h"
 #include "skymap.h"
 #include "ksasteroid.h"
+#include "kspluto.h"
+#include "ksplanet.h"
+#include "kssun.h"
+#include "ksmoon.h"
 
-KSPlanetBase::KSPlanetBase( KStarsData *kd, const QString &s, 		const QString &image_file, const QColor &c, double pSize )
-        : TrailObject( 2, 0.0, 0.0, 0.0, s ),
-        Rearth(0.0), Image(), data(kd),
-PhysicalSize(pSize), m_Color( c ) {
+QVector<QColor> KSPlanetBase::planetColor = QVector<QColor>() <<
+  QColor("slateblue") << //Mercury
+  QColor("lightgreen") << //Venus
+	QColor("red") << //Mars
+	QColor("goldenrod") << //Jupiter
+	QColor("khaki") << //Saturn
+	QColor("lightseagreen") << //Uranus
+	QColor("skyblue") << //Neptune
+	QColor("grey") << //Pluto
+	QColor("yellow") << //Sun
+  QColor("white"); //Moon
 
+
+KSPlanetBase::KSPlanetBase( KStarsData *kd, const QString &s, const QString &image_file, const QColor &c, double pSize )
+    : TrailObject( 2, 0.0, 0.0, 0.0, s ), Rearth(0.0), Image(), data(kd) {
+    init( s, image_file, c, pSize );
+}
+
+KSPlanetBase::KSPlanetBase( KSPlanetBase &o ) 
+    : TrailObject( (TrailObject &) o ) {
+    init( o.name(), "", o.color(), o.physicalSize() );
+    Image = *o.image();
+    Image0 = *o.image0();
+    data = KStarsData::Instance();
+}
+
+void KSPlanetBase::init( const QString &s, const QString &image_file, const QColor &c, double pSize ) {
     if (! image_file.isEmpty()) {
         QFile imFile;
 
@@ -48,6 +73,38 @@ PhysicalSize(pSize), m_Color( c ) {
     }
     PositionAngle = 0.0;
     ImageAngle = 0.0;
+    PhysicalSize = pSize;
+    m_Color = c;
+    setName( s );
+    setLongName( s );
+}
+
+KSPlanetBase* KSPlanetBase::createPlanet( int n ) {
+    KStarsData *kd = KStarsData::Instance();
+
+    switch ( n ) {
+        case KSPlanetBase::MERCURY:
+        case KSPlanetBase::VENUS:
+        case KSPlanetBase::MARS:
+        case KSPlanetBase::JUPITER:
+        case KSPlanetBase::SATURN:
+        case KSPlanetBase::URANUS:
+        case KSPlanetBase::NEPTUNE:
+            return new KSPlanet( kd, n );
+            break;
+
+        case KSPlanetBase::PLUTO:
+            return new KSPluto(kd);
+            break;
+        case KSPlanetBase::SUN:
+            return new KSSun(kd);
+            break;
+        case KSPlanetBase::MOON:
+            return new KSMoon(kd);
+            break;
+    }
+
+    return 0;
 }
 
 void KSPlanetBase::EquatorialToEcliptic( const dms *Obliquity ) {
@@ -89,9 +146,9 @@ void KSPlanetBase::findPosition( const KSNumbers *num, const dms *lat, const dms
 }
 
 bool KSPlanetBase::isMajorPlanet() const {
-    if ( name() == "Mercury" || name() == "Venus" || name() == "Mars" ||
-            name() == "Jupiter" || name() == "Saturn" || name() == "Uranus" ||
-            name() == "Neptune" )
+    if ( name() == i18n( "Mercury" ) || name() == i18n( "Venus" ) || name() == i18n( "Mars" ) ||
+         name() == i18n( "Jupiter" ) || name() == i18n( "Saturn" ) || name() == i18n( "Uranus" ) ||
+         name() == i18n( "Neptune" ) )
         return true;
     return false;
 }
@@ -211,7 +268,7 @@ double KSPlanetBase::labelOffset() const {
         size = minsize;
 
     //Inflate offset for Saturn
-    if ( name() == "Saturn" )
+    if ( name() == i18n( "Saturn" ) )
         size = int(2.5*size);
 
     return 0.5*size + 4.;
@@ -232,7 +289,6 @@ void KSPlanetBase::scaleRotateImage( float size, double imAngle ) {
 }
 
 void KSPlanetBase::findMagnitude(const KSNumbers *num) {
-
     double cosDec, sinDec;
     dec()->SinCos(cosDec, sinDec);
 
@@ -254,18 +310,18 @@ void KSPlanetBase::findMagnitude(const KSNumbers *num) {
     double param = 5 * log10(rsun() * rearth() );
     double f1 = phase/100.;
 
-    if ( name() == "Mercury" ) {
+    if ( name() == i18n( "Mercury" ) ) {
         if ( phase > 150. ) f1 = 1.5;
         magnitude = -0.36 + param + 3.8*f1 - 2.73*f1*f1 + 2*f1*f1*f1;
     }
-    if ( name() =="Venus")
+    if ( name() == i18n( "Venus" ) )
         magnitude = -4.29 + param + 0.09*f1 + 2.39*f1*f1 - 0.65*f1*f1*f1;
-    if( name() == "Mars")
+    if( name() == i18n( "Mars" ) )
         magnitude = -1.52 + param + 0.016*phase;
-    if( name() == "Jupiter")
+    if( name() == i18n( "Jupiter" ) )
         magnitude = -9.25 + param + 0.005*phase;
 
-    if( name() == "Saturn") {
+    if( name() == i18n( "Saturn" ) ) {
         double T = num->julianCenturies();
         double a0 = (40.66-4.695*T)* dms::PI / 180.;
         double d0 = (83.52+0.403*T)* dms::PI / 180.;
@@ -275,11 +331,11 @@ void KSPlanetBase::findMagnitude(const KSNumbers *num) {
         magnitude = -8.88 + param + 0.044*phase + rings;
     }
 
-    if( name() == "Uranus")
+    if( name() == i18n( "Uranus" ) )
         magnitude = -7.19 + param + 0.0028*phase;
-    if( name() == "Neptune")
+    if( name() == i18n( "Neptune" ) )
         magnitude = -6.87 + param;
-    if( name() == "Pluto" )
+    if( name() == i18n( "Pluto" ) )
         magnitude = -1.01 + param + 0.041*phase;
 
     if( type() == SkyObject::ASTEROID ) {
