@@ -32,7 +32,7 @@
 #include "starobject.h"
 #include "deepskyobject.h"
 
-QStringList CustomCatalogComponent::m_Columns = QString( "ID RA Dc Tp Nm Mg Mj Mn PA Ig" ).split( " ", QString::SkipEmptyParts );
+QStringList CustomCatalogComponent::m_Columns = QString( "ID RA Dc Tp Nm Mg Mj Mn PA Ig" ).split( ' ', QString::SkipEmptyParts );
 
 CustomCatalogComponent::CustomCatalogComponent(SkyComponent *parent, const QString &fname, bool showerrs, int index) : ListComponent(parent), m_Filename( fname ), m_Showerrs( showerrs ), m_ccIndex(index)
 {
@@ -59,12 +59,12 @@ void CustomCatalogComponent::init( KStarsData * ) {
         QStringList Columns; //list of data column descriptors in the header
 
         QTextStream stream( &ccFile );
-        QStringList lines = stream.readAll().split( "\n", QString::SkipEmptyParts );
+        QStringList lines = stream.readAll().split( '\n', QString::SkipEmptyParts );
 
         if ( parseCustomDataHeader( lines, Columns, iStart, m_Showerrs, errs ) ) {
 
             for ( int i=iStart; i < lines.size(); ++i ) {
-                QStringList d = lines.at(i).split( " ", QString::SkipEmptyParts );
+                QStringList d = lines.at(i).split( ' ', QString::SkipEmptyParts );
 
                 //Now, if one of the columns is the "Name" field, the name may contain spaces.
                 //In this case, the name field will need to be surrounded by quotes.
@@ -142,8 +142,8 @@ void CustomCatalogComponent::draw( QPainter &psky )
     if ( ! visible() ) return;
 
     SkyMap *map = SkyMap::Instance();
-    float Width  = map->scale() * map->width();
-    float Height = map->scale() * map->height();
+    //    float Width  = map->scale() * map->width();
+    //    float Height = map->scale() * map->height();
 
     psky.setBrush( Qt::NoBrush );
     psky.setPen( QColor( m_catColor ) );
@@ -181,9 +181,9 @@ bool CustomCatalogComponent::parseCustomDataHeader( const QStringList &lines, QS
     bool foundDataColumns( false ); //set to true if description of data columns found
     int ncol( 0 );
 
-    m_catName = QString();
-    m_catPrefix = QString();
-    m_catColor = QString();
+    m_catName.clear();
+    m_catPrefix.clear();
+    m_catColor.clear();
     m_catEpoch = 0.;
     int i=0;
     for ( ; i < lines.size(); ++i ) {
@@ -240,9 +240,9 @@ bool CustomCatalogComponent::parseCustomDataHeader( const QStringList &lines, QS
             }
         } else if ( ! foundDataColumns ) { //don't try to parse data column descriptors if we already found them
             //Chomp off leading "#" character
-            d = d.replace( QRegExp( "#" ), QString() );
+            d = d.remove( '#' );
 
-            QStringList fields = d.split( " ", QString::SkipEmptyParts ); //split on whitespace
+            QStringList fields = d.split( ' ', QString::SkipEmptyParts ); //split on whitespace
 
             //we need a copy of the master list of data fields, so we can
             //remove fields from it as they are encountered in the "fields" list.
