@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008 Torsten Rahn <tackat@kde.org>"
+// Copyright 2008 Torsten Rahn <tackat@kde.org>
 //
 
 
@@ -17,7 +17,8 @@
 #include "GeoDataLineString.h"
 
 
-using namespace Marble;
+namespace Marble
+{
 
 /**
  * @short A class that defines a closed, contiguous set of line segments.
@@ -35,10 +36,16 @@ using namespace Marble;
 
 class GEODATA_EXPORT GeoDataLinearRing : public GeoDataLineString {
  public:
-    GeoDataLinearRing();
+    explicit GeoDataLinearRing( GeoDataObject *parent = 0,          
+                                TessellationFlags f = NoTessellation);
 
     virtual ~GeoDataLinearRing();
+
+    virtual bool isClosed() const;
+
     virtual EnumGeometryId geometryId() const { return GeoDataLinearRingId; };
 };
 
+}
+
 #endif // GEODATALINEARRING_H
