@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlDocumentTagHandler : public GeoTagHandler {
-public:
-    DgmlDocumentTagHandler();
-    virtual ~DgmlDocumentTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlDocumentTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlDocumentTagHandler_h
