@@ -26,19 +26,12 @@
 #include "GPXElementDictionary.h"
 #include "GeoParser.h"
 
-using namespace GeoDataElementDictionary;
-
+namespace Marble
+{
+namespace gpx
+{
 GPX_DEFINE_TAG_HANDLER(gpx)
 
-GPXgpxTagHandler::GPXgpxTagHandler()
-    : GeoTagHandler()
-{
-}
-
-GPXgpxTagHandler::~GPXgpxTagHandler()
-{
-}
-
 GeoNode* GPXgpxTagHandler::parse(GeoParser& parser) const
 {
     Q_ASSERT(parser.isStartElement() && parser.isValidElement(gpxTag_gpx));
@@ -46,3 +39,6 @@ GeoNode* GPXgpxTagHandler::parse(GeoParser& parser) const
     qDebug() << "Parsed <Document> start!";    
     return 0;
 }
+
+}
+}
