@@ -27,19 +27,12 @@
 #include "GeoDataDocument.h"
 #include "GeoDataParser.h"
 
-using namespace GeoDataElementDictionary;
-
+namespace Marble
+{
+namespace kml
+{
 KML_DEFINE_TAG_HANDLER(Document)
 
-KmlDocumentTagHandler::KmlDocumentTagHandler()
-    : GeoTagHandler()
-{
-}
-
-KmlDocumentTagHandler::~KmlDocumentTagHandler()
-{
-}
-
 GeoNode* KmlDocumentTagHandler::parse(GeoParser& parser) const
 {
     Q_ASSERT(parser.isStartElement() && parser.isValidElement(kmlTag_Document));
@@ -50,3 +43,6 @@ GeoNode* KmlDocumentTagHandler::parse(GeoParser& parser) const
 #endif
     return doc;
 }
+
+}
+}
