@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlLineStyleTagHandler : public GeoTagHandler {
-public:
-    KmlLineStyleTagHandler();
-    virtual ~KmlLineStyleTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlLineStyleTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlLineStyleTagHandler_h
