@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlLinearRingTagHandler : public GeoTagHandler {
-public:
-    KmlLinearRingTagHandler();
-    virtual ~KmlLinearRingTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlLinearRingTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlLinearRingTagHandler_h
