@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlPointTagHandler : public GeoTagHandler {
-public:
-    KmlPointTagHandler();
-    virtual ~KmlPointTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlPointTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlPointTagHandler_h
