@@ -15,9 +15,13 @@
 
 #include "Waypoint.h"
 
-class ClipPainter;
 class QPoint;
 
+namespace Marble
+{
+
+class ClipPainter;
+
 /**
  * @brief An element of a Track
  */
@@ -30,7 +34,7 @@ class TrackPoint : public Waypoint
      * this initialises a trackpoint to a position and any other
      * information elements can be entered layer
      */
-    TrackPoint( double lat, double lon );
+    TrackPoint( qreal lat, qreal lon );
     TrackPoint( const TrackPoint& );
     
     /**
@@ -40,5 +44,6 @@ class TrackPoint : public Waypoint
     virtual void printToStream( QTextStream & ) const;
 };
 
+}
 
 #endif
